from setuptools import setup

setup(
    name = 'alphabet',
    version = '0.0.1',
    description = 'A string class enhancement',
    packages = [ 'alphabet' ],
    author = 'Roberto Reale',
    author_email = 'rober.reale@gmail.com',
    url = 'https://github.com/robertoreale/alphabet',
    keywords = [ ],
    install_requires = [ ]
)
